==> scripts-0.0.22.tgz: package/configs/webpack.dev.js <==
/* eslint-env node */
/* eslint-disable import/no-extraneous-dependencies, global-require, @typescript-eslint/no-var-requires, import/no-dynamic-require */

const path = require('path');
const webpack = require('webpack');
const merge = require('lodash.merge');
const HtmlPlugin = require('html-webpack-plugin');
const ForkTsCheckerWebpackPlugin = require('fork-ts-checker-webpack-plugin');
const styledComponentsTransformer = require('typescript-plugin-styled-components').default;

const config = require('./app-config');

const mode = 'development';
const transformer = styledComponentsTransformer();

let webpackDev = {
  mode,
  devtool: 'inline-source-map',
  entry: {
    app: [require.resolve('react-hot-loader/patch'), config.app],
  },
  output: {
    path: config.output,
    publicPath: '/',
    filename: '[name].bundle.js',
    chunkFilename: '[name].chunk.js',
  },
  watchOptions: {
    ignored: /node_modules\/(?!@cfw\/*)/,
    aggregateTimeout: 300,
    poll: 1000,
  },
  module: {
    rules: [
      {
        test: /\.(js|jsx|ts|tsx)$/,
        exclude: /node_modules\/(?!@cfw*|(strip-)?ansi)/,
        loader: 'ts-loader',
        options: {
          transpileOnly: true,
          happyPackMode: true,
          allowTsInNodeModules: true,
          getCustomTransformers: () => ({before: [transformer]}),
        },
      },
      {
        test: /\.(jpe?g|png|gif|ico|webp)$/i,
        type: 'asset/resource',
      },
      {
        test: /\.(css)$/i,
        type: 'asset/source',
      },
      {
        test: /\.svg/,
        exclude: /node_modules\/(?!@cfwi*)/,
        loader: 'svg-react-loader',
      },
    ],
  },
  resolve: {
    extensions: ['.js', '.jsx', '.ts', '.tsx', '.json'],
    modules: [path.resolve(config.cwd, './node_modules'), 'node_modules'],
    alias: {
      src: config.src,
      'react-dom': '@hot-loader/react-dom',
      '@cfw/components': path.resolve(config.cwd, '../cfw/packages/components'),
      '@cfw/styles': path.resolve(config.cwd, '../cfw/packages/styles'),
      '@cfw/utils': path.resolve(config.cwd, '../cfw/packages/utils'),
      '@cfw/models': path.resolve(config.cwd, '../cfw/packages/models'),
      '@cfw/icons': path.resolve(config.cwd, '../cfw/packages/icons'),
    },
  },
  plugins: [
    new webpack.HotModuleReplacementPlugin(),
    new webpack.IgnorePlugin(/^\.\/locale$/, /moment$/),
    new ForkTsCheckerWebpackPlugin(),
    new HtmlPlugin({
      template: config.template,
      base: '/',
      minify: false,
    }),
    new webpack.DefinePlugin({
      BUILDINFO: {
        name: JSON.stringify(config.name),
        version: JSON.stringify(config.version),
        timestamp: JSON.stringify(new Date().toISOString()),
      },
      'process.env.NODE_ENV': JSON.stringify(mode),
    }),
  ].filter(Boolean),
};

webpackDev = merge(webpackDev, config.webpackOverrides.development);

module.exports = webpackDev;

/* eslint-enable import/no-extraneous-dependencies, global-require, @typescript-eslint/no-var-requires, import/no-dynamic-require */

==> scripts-0.0.25.tgz: package/configs/webpack.dev.js <==
/* eslint-env node */
/* eslint-disable import/no-extraneous-dependencies, global-require, @typescript-eslint/no-var-requires, import/no-dynamic-require */

const path = require('path');
const webpack = require('webpack');
const merge = require('lodash.merge');
const HtmlPlugin = require('html-webpack-plugin');
const ForkTsCheckerWebpackPlugin = require('fork-ts-checker-webpack-plugin');
const styledComponentsTransformer = require('typescript-plugin-styled-components').default;

const config = require('./app-config');

const mode = 'development';
const transformer = styledComponentsTransformer();

let webpackDev = {
  mode,
  devtool: 'inline-source-map',
  entry: {
    app: [require.resolve('react-hot-loader/patch'), config.app],
  },
  output: {
    path: config.output,
    publicPath: '/',
    filename: '[name].bundle.js',
    chunkFilename: '[name].chunk.js',
  },
  watchOptions: {
    ignored: /node_modules\/(?!@callfromweb\/*)/,
    aggregateTimeout: 300,
    poll: 1000,
  },
  module: {
    rules: [
      {
        test: /\.(js|jsx|ts|tsx)$/,
        exclude: /node_modules\/(?!@callfromweb*|(strip-)?ansi)/,
        loader: 'ts-loader',
        options: {
          transpileOnly: true,
          happyPackMode: true,
          allowTsInNodeModules: true,
          getCustomTransformers: () => ({before: [transformer]}),
        },
      },
      {
        test: /\.(jpe?g|png|gif|ico|webp)$/i,
        type: 'asset/resource',
      },
      {
        test: /\.(css)$/i,
        type: 'asset/source',
      },
      {
        test: /\.svg/,
        exclude: /node_modules\/(?!@callfromwebi*)/,
        loader: 'svg-react-loader',
      },
    ],
  },
  resolve: {
    extensions: ['.js', '.jsx', '.ts', '.tsx', '.json'],
    modules: [path.resolve(config.cwd, './node_modules'), 'node_modules'],
    alias: {
      src: config.src,
      'react-dom': '@hot-loader/react-dom',
      '@callfromweb/components': path.resolve(config.cwd, '../cfw/packages/components'),
      '@callfromweb/styles': path.resolve(config.cwd, '../cfw/packages/styles'),
      '@callfromweb/utils': path.resolve(config.cwd, '../cfw/packages/utils'),
      '@callfromweb/models': path.resolve(config.cwd, '../cfw/packages/models'),
      '@callfromweb/icons': path.resolve(config.cwd, '../cfw/packages/icons'),
    },
  },
  plugins: [
    new webpack.HotModuleReplacementPlugin(),
    new webpack.IgnorePlugin(/^\.\/locale$/, /moment$/),
    new ForkTsCheckerWebpackPlugin(),
    new HtmlPlugin({
      template: config.template,
      base: '/',
      minify: false,
    }),
    new webpack.DefinePlugin({
      BUILDINFO: {
        name: JSON.stringify(config.name),
        version: JSON.stringify(config.version),
        timestamp: JSON.stringify(new Date().toISOString()),
      },
      'process.env.NODE_ENV': JSON.stringify(mode),
    }),
  ].filter(Boolean),
};

webpackDev = merge(webpackDev, config.webpackOverrides.development);

module.exports = webpackDev;

/* eslint-enable import/no-extraneous-dependencies, global-require, @typescript-eslint/no-var-requires, import/no-dynamic-require */
